@@ -848,8 +848,10 @@ class StageInClient(StagingClient):
         kwargs['activity'] = activity
 
         # verify file sizes and available space for stage-in
-        self.check_availablespace(remain_files)
-
+        if self.infosys.queuedata.maxinputsize != -1:
+            self.check_availablespace(remain_files)
+        else:
+            self.logger.info('skipping input file size check since maxinputsize=-1')
         show_memory_usage()
 
         # add the trace report
