@@ -6,6 +6,7 @@
 #
 # Authors:
 # - Paul Nilsson, paul.nilsson@cern.ch, 2017-2020
+# - Alexander Bogdanchikov, Alexander.Bogdanchikov@cern.ch, 2019-2020
 
 import os
 import pipes
@@ -15,16 +16,59 @@ import re
 from pilot.common.errorcodes import ErrorCodes
 from pilot.common.exception import PilotException
 from pilot.user.atlas.setup import get_asetup, get_file_system_root_path
+from pilot.user.atlas.proxy import verify_proxy
 from pilot.info import InfoService, infosys
+from pilot.util.auxiliary import is_python3
 from pilot.util.config import config
 from pilot.util.filehandling import write_file
 
+# imports for get_payload_proxy()
+from pilot.util import https
+import traceback
+
 import logging
 logger = logging.getLogger(__name__)
-
 errors = ErrorCodes()
 
 
+def get_payload_proxy(proxy_outfile_name, voms_role='atlas'):
+    """
+    :param proxy_outfile_name: specify the file to store proxy
+    :param voms_role: what proxy (role) to request. It should exist on Panda node
+    :return: True on success
+    """
+    try:
+        # it assumes that https_setup() was done already
+        res = https.request('{pandaserver}/server/panda/getProxy'.format(pandaserver=config.Pilot.pandaserver),
+                            data={'role': voms_role})
+
+        if res is None:
+            logger.error("Unable to get proxy with role '%s' from panda server" % voms_role)
+            return False
+
+        if res['StatusCode'] != 0:
+            logger.error("When get proxy with role '%s' panda server returned: %s" % (voms_role, res['errorDialog']))
+            return False
+
+        proxy_contents = res['userProxy']
+
+    except Exception as e:
+        logger.error("Get proxy from panda server failed: %s, %s" % (e, traceback.format_exc()))
+        return False
+
+    res = False
+    try:
+        # pre-create empty proxy file with secure permissions. Prepare it for write_file() which can not
+        # set file permission mode, it will writes to the existing file with correct permissions.
+        f = os.open(proxy_outfile_name, os.O_WRONLY | os.O_CREAT | os.O_TRUNC, 0o600)
+        os.close(f)
+        res = write_file(proxy_outfile_name, proxy_contents, mute=False)  # returns True on success
+    except Exception as e:
+        logger.error("Exception when try to save proxy to the file '%s': %s, %s" % (proxy_outfile_name, e, traceback.format_exc()))
+
+    return res
+
+
 def do_use_container(**kwargs):
     """
     Decide whether to use a container or not.
@@ -259,7 +303,7 @@ def update_alrb_setup(cmd, use_release_setup):
     return updated_cmd
 
 
-def update_for_user_proxy(_cmd, cmd):
+def update_for_user_proxy_old(_cmd, cmd):
     """
     Add the X509 user proxy to the container sub command string if set, and remove it from the main container command.
 
@@ -278,6 +322,72 @@ def update_for_user_proxy(_cmd, cmd):
     return _cmd, cmd
 
 
+def update_for_user_proxy(_cmd, cmd):
+    """
+    Add the X509 user proxy to the container sub command string if set, and remove it from the main container command.
+    Try to receive payload proxy and update X509_USER_PROXY in container setup command
+    In case payload proxy from server is required, this function will also download and verify this proxy.
+
+    :param _cmd: container setup command
+    :param cmd: command the container will execute
+    :return: exit_code (int), diagnostics (string), updated _cmd (string), updated cmd (string).
+    """
+
+    exit_code = 0
+    diagnostics = ""
+
+    x509 = os.environ.get('X509_USER_PROXY', '')
+    if x509 != "":
+        # do not include the X509_USER_PROXY in the command the container will execute
+        cmd = cmd.replace("export X509_USER_PROXY=%s;" % x509, '')
+        # add it instead to the container setup command:
+
+        # download and verify payload proxy from the server if desired
+        if config.Pilot.payload_proxy_from_server:
+            exit_code, diagnostics, x509 = get_and_verify_payload_proxy_from_server(x509)
+            if exit_code != 0:  # do not return non-zero exit code if only download fails
+                logger.warning('payload proxy verification failed')
+
+        # add X509_USER_PROXY setting to the container setup command
+        _cmd = "export X509_USER_PROXY=%s;" % x509 + _cmd
+
+    return exit_code, diagnostics, _cmd, cmd
+
+
+def get_and_verify_payload_proxy_from_server(x509):
+    """
+    Download a payload proxy from the server and verify it.
+
+    :param x509: X509_USER_PROXY (string).
+    :return:  exit code (int), diagnostics (string), updated X509_USER_PROXY (string).
+    """
+
+    exit_code = 0
+    diagnostics = ""
+
+    # try to receive payload proxy and update x509
+    x509_payload = re.sub('.proxy$', '', x509) + '-payload.proxy'  # compose new name to store payload proxy
+    #x509_payload = re.sub('.proxy$', '', x509) + 'p.proxy'  # compose new name to store payload proxy
+
+    logger.info("download payload proxy from server")
+    if get_payload_proxy(x509_payload):
+        logger.info("server returned payload proxy (verifying)")
+        exit_code, diagnostics = verify_proxy(x509=x509_payload, proxy_id=None)
+        # if all verifications fail, verify_proxy()  returns exit_code=0 and last failure in diagnostics
+        if exit_code != 0 or (exit_code == 0 and diagnostics != ''):
+            logger.warning(diagnostics)
+            logger.info("payload proxy verification failed")
+        else:
+            logger.info("payload proxy verified")
+            # is commented: no user proxy should be in the command the container will execute
+            # cmd = cmd.replace("export X509_USER_PROXY=%s;" % x509, "export X509_USER_PROXY=%s;" % x509_payload)
+            x509 = x509_payload
+    else:
+        logger.warning("get_payload_proxy() failed")
+
+    return exit_code, diagnostics, x509
+
+
 def set_platform(job, alrb_setup):
     """
     Set thePlatform variable and add it to the sub container command.
@@ -392,8 +502,10 @@ def alrb_wrapper(cmd, workdir, job=None):
         logger.debug('initial alrb_setup: %s' % alrb_setup)
 
         # add user proxy if necessary (actually it should also be removed from cmd)
-        alrb_setup, cmd = update_for_user_proxy(alrb_setup, cmd)
-
+        exit_code, diagnostics, alrb_setup, cmd = update_for_user_proxy(alrb_setup, cmd)
+        if exit_code:
+            job.piloterrordiag = diagnostics
+            job.piloterrorcodes, job.piloterrordiags = errors.add_error_code(exit_code)
         # set the platform info
         alrb_setup = set_platform(job, alrb_setup)
 
@@ -586,18 +698,63 @@ def create_release_setup(cmd, atlas_setup, full_atlas_setup, release, imagename,
     :return: proper release setup name (string), updated cmd (string).
     """
 
+    release_setup_name = '/srv/my_release_setup.sh'
+
+    # extracted_asetup should be written to 'my_release_setup.sh' and cmd to 'container_script.sh'
+    content = 'echo \"INFO: sourcing %s inside the container. ' \
+              'This should not run if it is a ATLAS standalone container\"' % release_setup_name
+    if is_cvmfs and release and release != 'NULL':
+        content, cmd = extract_full_atlas_setup(cmd, atlas_setup)
+        if not content:
+            content = full_atlas_setup
+
+    content += '\nreturn $?'
+    logger.debug('command to be written to release setup file:\n\n%s:\n\n%s\n' % (release_setup_name, content))
+    try:
+        write_file(os.path.join(workdir, os.path.basename(release_setup_name)), content, mute=False)
+    except Exception as e:
+        logger.warning('exception caught: %s' % e)
+
+    # reset cmd in case release_setup.sh does not exist in unpacked image (only for those containers)
+    if imagename and release and release != 'NULL':
+        cmd = cmd.replace(';;', ';') if is_release_setup(release_setup_name, imagename) else ''
+
+    return release_setup_name, cmd
+
+
+def create_release_setup_old(cmd, atlas_setup, full_atlas_setup, release, imagename, workdir, is_cvmfs):
+    """
+    Get the proper release setup script name, and create the script if necessary.
+
+    This function also updates the cmd string (removes full asetup from payload command).
+
+    Note: for stand-alone containers, the function will return /release_setup.sh and assume that this script exists
+    in the container. The pilot will only create a my_release_setup.sh script for OS containers.
+
+    In case the release setup is not present in an unpacked container, the function will reset the cmd string.
+
+    :param cmd: Payload execution command (string).
+    :param atlas_setup: asetup command (string).
+    :param full_atlas_setup: full asetup command (string).
+    :param release: software release, needed to determine Athena environment (string).
+    :param imagename: container image name (string).
+    :param workdir: job workdir (string).
+    :param is_cvmfs: does the queue have cvmfs? (Boolean).
+    :return: proper release setup name (string), updated cmd (string).
+    """
+
     release_setup_name = get_release_setup_name(release, imagename)
 
     # note: if release_setup_name.startswith('/'), the pilot will NOT create the script
     if not release_setup_name.startswith('/'):
         # extracted_asetup should be written to 'my_release_setup.sh' and cmd to 'container_script.sh'
-        content = ''
+        content = 'echo \"INFO: sourcing %s inside the container. ' \
+                  'This should not run if it is a ATLAS standalone container\"' % release_setup_name
         if is_cvmfs:
             content, cmd = extract_full_atlas_setup(cmd, atlas_setup)
             if not content:
                 content = full_atlas_setup
         if not content:
-            content = 'echo \"Error: this setup file should not be run since %s should exist inside the container\"' % release_setup_name
             logger.debug(
                 'will create an empty (almost) release setup file since asetup could not be extracted from command')
         logger.debug('command to be written to release setup file:\n\n%s:\n\n%s\n' % (release_setup_name, content))
@@ -634,9 +791,9 @@ def get_release_setup_name(release, imagename):
 
     if imagename and release and release != 'NULL':
         # stand-alone containers (script is assumed to exist inside image/container so will ignore this /srv/my_release_setup.sh)
-        #        release_setup_name = '/srv/my_release_setup.sh'
+        release_setup_name = '/srv/my_release_setup.sh'
         # stand-alone containers (script is assumed to exist inside image/container)
-        release_setup_name = '/release_setup.sh'
+        # release_setup_name = '/release_setup.sh'
     else:
         # OS containers (script will be created by pilot)
         release_setup_name = config.Container.release_setup
@@ -824,21 +981,33 @@ def get_root_container_script(cmd):
     return content
 
 
-def get_middleware_container_script(middleware_container, cmd):
+def get_middleware_container_script(middleware_container, cmd, asetup=False):
     """
     Return the content of the middleware container script.
+    If asetup is True, atlasLocalSetup will be added to the command.
 
     :param middleware_container: container image (string).
     :param cmd: isolated stage-in/out command (string).
+    :param asetup: optional True/False (boolean).
     :return: script content (string).
     """
 
-    content = 'export PILOT_RUCIO_SITENAME=%s; ' % os.environ.get('PILOT_RUCIO_SITENAME')
+    sitename = 'export PILOT_RUCIO_SITENAME=%s; ' % os.environ.get('PILOT_RUCIO_SITENAME')
     if 'rucio' in middleware_container:
-        content += 'python3 %s\nexit $?' % cmd
+        content = sitename + 'python3 %s ' % cmd  # only works with python 3
     else:
-        content += 'lsetup rucio davix xrootd;python %s\nexit $?' % cmd
-    logger.debug('setup.sh content:\n%s' % content)
+        content = ''
+        if is_python3():
+            content += 'export ALRB_LOCAL_PY3=YES; '
+        if asetup:  # export ATLAS_LOCAL_ROOT_BASE=/cvmfs/..;source ${ATLAS_LOCAL_ROOT_BASE}/user/atlasLocalSetup.sh --quiet;
+            content += get_asetup(asetup=False)
+        content += sitename + 'lsetup rucio davix xrootd; '
+        content += 'python3 %s ' % cmd if is_python3() else 'python %s' % cmd
+
+    if not asetup:
+        content += '\nexit $?'
+
+    logger.debug('content:\n%s' % content)
 
     return content
 
